@@ -1,11 +1,8 @@
 /**
- * Nodes.js
- *
- * Released under LGPL License.
- * Copyright (c) 1999-2017 Ephox Corp. All rights reserved
- *
- * License: http://www.tinymce.com/license
- * Contributing: http://www.tinymce.com/contributing
+ * Copyright (c) Tiny Technologies, Inc. All rights reserved.
+ * Licensed under the LGPL or a commercial license.
+ * For LGPL see License.txt in the project root for license information.
+ * For commercial licenses see https://www.tiny.cloud/
  */
 
 import { Arr } from '@ephox/katamari';
@@ -14,9 +11,10 @@ import Data from './Data';
 import Html from './Html';
 
 const isMatch = function (n) {
+  const value = Node.value(n);
   return Node.isText(n) &&
-    Node.value(n) !== undefined &&
-    Data.regExp.test(Node.value(n));
+    value !== undefined &&
+    Data.regExp.test(value);
 };
 
 // inlined sugars PredicateFilter.descendants for file size
@@ -43,8 +41,8 @@ const findParentElm = function (elm, rootElm) {
   }
 };
 
-const replaceWithSpans = function (html) {
-  return html.replace(Data.regExpGlobal, Html.wrapCharWithSpan);
+const replaceWithSpans = function (text: string) {
+  return text.replace(Data.regExpGlobal, Html.wrapCharWithSpan);
 };
 
 export default {
